@@ -2,7 +2,7 @@ from base64 import b64encode, b64decode
 from getpass import getpass
 
 from easyshare.utils.crypt import scrypt, scrypt_new, bytes_to_b64, b64_to_bytes, str_to_b64
-from easyshare.utils.types import str_to_bytes
+from easyshare.utils.types import stob
 
 
 def main():
@@ -42,8 +42,8 @@ if __name__ == "__main__":
     print("salt2", salt2)
 
     # s = "pippo"
-    # s2 = b64decode(b64encode(str_to_bytes(s)))
-    # sb = str_to_bytes(s)
+    # s2 = b64decode(b64encode(stob(s)))
+    # sb = stob(s)
     # s2 = bytes_to_b64(b64_to_bytes(sb))
     # print(s)
     # print(s2)
