@@ -3,7 +3,7 @@ import ssl
 from easyshare.sockets import SocketTcpOut
 
 
-from easyshare.utils.types import  str_to_bytes
+from easyshare.utils.types import  stob
 
 host = "192.168.1.105"
 port = 5555
@@ -24,7 +24,7 @@ def main():
         print("Peer cert:", sslsock.getpeercert())
         while True:
             msg = input("$ ")
-            sslsock.send(str_to_bytes(msg))
+            sslsock.send(stob(msg))
 
 
 if __name__ == "__main__":
