@@ -2,7 +2,7 @@ import ssl
 
 from easyshare.sockets import SocketTcpAcceptor
 from easyshare.utils.ssl import create_server_ssl_context
-from easyshare.utils.types import bytes_to_str
+from easyshare.utils.types import btos
 
 
 host = "localhost"
@@ -23,7 +23,7 @@ def main():
         print("Connection received from", endpoint)
         while True:
             inraw = ns.recv(1024)
-            print("<< " + bytes_to_str(inraw))
+            print("<< " + btos(inraw))
 
 
 if __name__ == "__main__":
