@@ -5,7 +5,7 @@ from easyshare.common import DIR_COLOR, FILE_COLOR
 from easyshare.logging import get_logger
 from easyshare.protocol.types import ServerInfoFull, FTYPE_DIR, FileInfo, SharingInfo, FTYPE_FILE
 from easyshare.ssl import get_cached_or_fetch_ssl_certificate_for_endpoint
-from easyshare.styling import fg, bold
+from easyshare.styling import fg, bold, underline
 from easyshare.tree import TreeNodeDict, TreeRenderPreOrder
 from easyshare.utils.env import terminal_size, is_unicode_supported
 from easyshare.utils.json import j
@@ -14,6 +14,7 @@ from easyshare.utils.os import perm_str
 from easyshare.utils.path import is_hidden
 from easyshare.utils.ssl import SSLCertificate
 from easyshare.utils.str import tf, yn
+from easyshare.utils.time import ns2timestamp
 
 log = get_logger(__name__)
 
@@ -42,28 +43,28 @@ def print_tabulated(strings: List[StyledString], max_columns: int = None,
     if not strings:
         return
 
-    log.d("print_tabulated - len(strings) %d", len(strings))
+    log.h(f"print_tabulated - len(strings) {len(strings)}")
 
     term_cols, _ = terminal_size()
-    log.d("print_tabulated - term_cols %d", term_cols)
+    log.h(f"print_tabulated - term_cols {term_cols}")
 
     longest_string_length = len(str(max(strings, key=lambda ss: len(str(ss)))))
-    log.d("print_tabulated - longest_match_length %d", longest_string_length)
+    log.h(f"print_tabulated - longest_match_length {longest_string_length}")
 
     min_col_width = longest_string_length + 2
-    log.d("print_tabulated - min_col_width %d", min_col_width)
+    log.h(f"print_tabulated - min_col_width {min_col_width}")
 
     max_allowed_cols = max_columns if max_columns else 50
-    log.d("print_tabulated - max_allowed_cols %d", max_allowed_cols)
+    log.h(f"print_tabulated - max_allowed_cols {max_allowed_cols}")
 
     max_fillable_cols = term_cols // min_col_width
-    log.d("print_tabulated - max_fillable_cols %d", max_fillable_cols)
+    log.h(f"print_tabulated - max_fillable_cols {max_fillable_cols}")
 
     display_cols = max(1, min(max_allowed_cols, max_fillable_cols))
-    log.d("print_tabulated - display_cols %d", display_cols)
+    log.h(f"print_tabulated - display_cols {display_cols}")
 
     display_rows = ceil(len(strings) / display_cols)
-    log.d("print_tabulated - display_rows %d", display_rows)
+    log.h(f"print_tabulated - display_rows {display_rows}")
 
     for r in range(0, display_rows):
         print_row = ""
@@ -81,27 +82,41 @@ def print_tabulated(strings: List[StyledString], max_columns: int = None,
         print_func(print_row + "\n")
 
 
-def file_info_full_str(info: FileInfo):
-    s = f"""\
-File:           {info.get("name")}    
-Type:           {info.get("ftype")}
-Size:           {info.get("size")}
-Last modified:  {info.get("mtime")}"""
-    return s
+def file_info_pretty_str(info: FileInfo, **kwargs):
+    details = []
+    if "name" in info:
+        details.append(f"File:           {info.get('name')}")
+    if "ftype" in info:
+        details.append(f"Type:           {info.get('ftype')}")
+    if "size" in info:
+        details.append(f"Size:           {info.get('size')}")
+    if "mtime" in info:
+        details.append(f"Last modified:  {ns2timestamp(info.get('mtime'))}")
+    if "user" in info:
+        details.append(f"User:           {info.get('user')}")
+    if "group" in info:
+        details.append(f"Group:          {info.get('group')}")
+    if "perm" in info:
+        details.append(f"Permissions:    {info.get('perm')}")
 
-def file_info_str(info: FileInfo,
-                  show_file_type: bool = False,  # -l
-                  show_size: bool = False,  # -S
-                  show_hidden: bool = False,  # -a
-                  show_perm: bool = False, # -l
-                  show_owner: bool = False, # -l
-                  owner_user_justify: int = 0,  # -l
-                  owner_group_justify: int = 0,  # -l
-                  **kwargs) -> Optional[StyledString]:
+    return "\n".join(details)
+
+def file_info_pretty_sstr(info: FileInfo, **kwargs):
+    return StyledString(file_info_pretty_str(info, **kwargs))
+
+def file_info_inline_sstr(info: FileInfo,
+                          show_file_type: bool = False,  # -l
+                          show_size: bool = False,  # -S
+                          show_hidden: bool = False,  # -a
+                          show_perm: bool = False,  # -l
+                          show_owner: bool = False,  # -l
+                          owner_user_justify: int = 0,  # -l
+                          owner_group_justify: int = 0,  # -l
+                          **kwargs) -> Optional[StyledString]:
     fname = info.get("name")
 
     if not show_hidden and is_hidden(fname):
-        log.d("Not showing hidden files: %s", fname)
+        log.d(f"Not showing hidden files: {fname}")
         return None
 
     if info.get("ftype") == FTYPE_DIR:
@@ -117,11 +132,21 @@ def file_info_str(info: FileInfo,
         file_str += ftype_short + " "
 
     if show_perm:
-        file_str += perm_str(info.get("perm")) + "  "
+        if "perm" in info:
+            file_str += perm_str(info.get("perm")) + "  "
+        else:
+            log.w("'perm' not found in file info")
 
     if show_owner:
-        file_str += info.get("user").ljust(owner_user_justify) + "  "
-        file_str += info.get("group").ljust(owner_group_justify) + "  "
+        if "user" in info:
+            file_str += info.get("user").ljust(owner_user_justify) + "  "
+        else:
+            log.w("'user' not found in file info")
+
+        if "group" in info:
+            file_str += info.get("group").ljust(owner_group_justify) + "  "
+        else:
+            log.w("'group' not found in file info")
 
     if show_size:
         file_str += size_str_justify(info.get("size")) + "  "
@@ -134,25 +159,24 @@ def file_info_str(info: FileInfo,
 
 
 def print_files_info_list(infos: List[FileInfo],
-                          show_hidden: bool = False,    # -a
-                          show_file_type: bool = False, # -l
-                          show_size: bool = False,      # -S
-                          show_perm: bool = False,      # -l
-                          show_owner: bool = False,     # -l
-                          compact: bool = True,         # not -l
-                          file_info_renderer: Callable[..., StyledString] = file_info_str):
+                          show_hidden: bool = False,  # -a
+                          show_file_type: bool = False,  # -l
+                          show_size: bool = False,  # -S
+                          show_perm: bool = False,  # -l
+                          show_owner: bool = False,  # -l
+                          compact: bool = True,  # not -l
+                          file_info_renderer: Callable[..., StyledString] = file_info_inline_sstr):
     """ Prints a list of 'FileInfo' (ls -l like). """
     if not infos:
         return
-
     # Detect the longest user/group length for render properly
     longest_user = 0
     longest_group = 0
     if show_owner:
         for i in infos:
-            if len(i.get("user")) > longest_user:
+            if "user" in i and len(i.get("user")) > longest_user:
                 longest_user = len(i.get("user"))
-            if len(i.get("group")) > longest_group:
+            if "group" in i and len(i.get("group")) > longest_group:
                 longest_group = len(i.get("group"))
 
     sstrings: List[StyledString] = [ss for ss in (
@@ -182,12 +206,12 @@ def print_files_info_tree(root: TreeNodeDict,
     """ Traverse the 'TreeNodeDict' and prints the 'FileInfo' as a tree (tree like). """
 
     for prefix, node, depth in TreeRenderPreOrder(root, depth=max_depth):
-        log.d("TreeRenderPostOrder over %s", j(node))
+        log.d(f"TreeRenderPostOrder over {j(node)}")
 
         name = node.get("name")
 
         if not show_hidden and is_hidden(name):
-            log.d("Not showing hidden file: %s", name)
+            log.d(f"Not showing hidden file: {name}")
             continue
 
         ftype = node.get("ftype")
@@ -199,6 +223,83 @@ def print_files_info_tree(root: TreeNodeDict,
             fg(name, color=DIR_COLOR if ftype == FTYPE_DIR else FILE_COLOR),
         ))
 
+def server_pretty_str(info: ServerInfoFull,
+                      show_server_info: bool = True,
+                      show_ssl_certificate: bool = True,
+                      show_sharings: bool = True,
+                      show_sharings_details: bool = True,
+                      highlight_sharings: List[SharingInfo] = None) -> str:
+    """ Returns a string representation of a 'ServerInfoFull' """
+
+    s = """\
+================================"""
+
+    # Server info?
+    if show_server_info:
+        s += f"""\
+
+{bold("SERVER INFO")}
+
+{server_info_pretty_str(info)}
+
+================================"""
+
+    # SSL?
+    if show_ssl_certificate:
+        if info.get("ssl"):
+            ssl_cert = get_cached_or_fetch_ssl_certificate_for_endpoint(
+                (info.get("ip"), info.get("port"))
+            )
+
+            s += f"""
+
+{bold("SSL CERTIFICATE")}
+
+{ssl_certificate_pretty_str(ssl_cert)}
+
+================================"""
+
+    # Sharings?
+    if show_sharings:
+        s += f"""
+
+{bold("SHARINGS")}
+
+{sharings_pretty_str(info.get("sharings"), 
+                     details=show_sharings_details, 
+                     indent=2,
+                     highlight_sharings=highlight_sharings)}
+
+================================"""
+
+    return s
+
+
+
+def server_info_pretty_str(info: ServerInfoFull) -> str:
+    """ Returns a string representation of a 'ServerInfoFull', apart from SSL and sharings """
+
+    discover_port_str = ""
+    if info.get("discoverable", False):
+        discover_port_str = "Discover Port:    {}\n".format(info.get("discover_port"))
+
+    return f"""\
+Name:             {info.get("name")}
+Address:          {info.get("ip")}
+Port:             {info.get("port")}
+Discoverable:     {yn(info.get("discoverable", False))}
+{discover_port_str}\
+Authentication:   {yn(info.get("auth"))}
+SSL:              {tf(info.get("ssl"), "enabled", "disabled")}
+Remote execution: {tf(info.get("rexec"), "enabled", "disabled")}
+Version:          {info.get("version")}"""
+
+
+def server_info_short_str(server_info: ServerInfoFull):
+    """ Returns a compact string representation of a 'ServerInfoFull' """
+
+    return f"{server_info.get('name')} ({server_info.get('ip')}:{server_info.get('port')})"
+
 
 def ssl_certificate_pretty_str(ssl_cert: SSLCertificate) -> str:
     """ Returns a string representation of a 'SSLCertificate' """
@@ -223,65 +324,10 @@ Issuer:             {", ".join([issuer.get("common_name"), issuer.get("organizat
 Signing:            {"self signed" if ssl_cert.get("self_signed") else "signed"}"""
 
 
-def server_info_pretty_str(info: ServerInfoFull, sharing_details: bool = False, separators: bool = False) -> str:
-    """ Returns a string representation of a 'ServerInfoFull' """
-
-    discover_port_str = ""
-    if info.get("discoverable", False):
-        discover_port_str = "Discover Port:    {}\n".format(info.get("discover_port"))
-
-
-    s = f"""\
-================================
-
-{bold("SERVER INFO")}
-
-Name:             {info.get("name")}
-Address:          {info.get("ip")}
-Port:             {info.get("port")}
-Discoverable:     {yn(info.get("discoverable", False))}
-{discover_port_str}\
-Authentication:   {yn(info.get("auth"))}
-SSL:              {tf(info.get("ssl"), "enabled", "disabled")}
-Remote execution: {tf(info.get("rexec"), "enabled", "disabled")}
-Version:          {info.get("version")}
-
-================================"""
-
-    # SSL?
-    if info.get("ssl"):
-        ssl_cert = get_cached_or_fetch_ssl_certificate_for_endpoint(
-            (info.get("ip"), info.get("port"))
-        )
-
-        s += f"""
-
-{bold("SSL CERTIFICATE")}
-
-{ssl_certificate_pretty_str(ssl_cert)}
-
-================================"""
-
-    # Sharings
-    s += f"""
-
-{bold("SHARINGS")}
-
-{sharings_pretty_str(info.get("sharings"), details=sharing_details, indent=2)}
-
-================================"""
-
-    return s
-
-def server_info_short_str(server_info: ServerInfoFull):
-    """ Returns a compact string representation of a 'ServerInfoFull' """
-
-    return f"{server_info.get('name')} ({server_info.get('ip')}:{server_info.get('port')})"
-
-
 def sharings_pretty_str(sharings: List[SharingInfo],
                         details: bool = False,
-                        indent: int = 0) -> str:
+                        indent: int = 0,
+                        highlight_sharings: List[SharingInfo] = None) -> str:
     """ Returns a string representation of a list of 'Sharing' """
 
     if sharings is None:
@@ -294,7 +340,12 @@ def sharings_pretty_str(sharings: List[SharingInfo],
     f_sharings = [sh for sh in sharings if sh.get("ftype") == FTYPE_FILE]
 
     def sharing_string(sharing: SharingInfo):
-        ss = " " * indent + bullet + " " + sharing.get("name")
+        ss = " " * indent + bullet + " "
+
+        if highlight_sharings and sharing in highlight_sharings:
+            ss += underline(sharing.get("name"))
+        else:
+            ss += sharing.get("name")
 
         if details:
             details_list = []
